# !/usr/bin/env python
# coding:utf-8

# Copyright (c) 2021. quinn.7@foxmail.com All rights reserved.

# Based on the Apache License 2.0 open source protocol.

__author__ = 'quinn.7@foxmail.com'


from rains.common.decorator import singleton_pattern


@singleton_pattern
class CaseRecorder(object):
    """
    用例记录器

    * 该模块负责记录用例执行时产生的日志，并且暂存至下一次读取。

    """

    _record_count: int
    """ 记录计数器 """

    _record_list: list
    """ 记录列表 """

    def __init__(self):
        """
        初始化
        """
        self._record_count = 0
        self._record_list = []

    @property
    def record_count(self):
        return self._record_count

    @property
    def record_list(self):
        return self._record_list

    def write(self, record: str):
        """
        录入
        """
        self._record_list.append(f'{ self._record_count }:: { record }')
        self._record_count += 1

    def read(self) -> str:
        """
        读取

        Return:
            所有记录拼接成的字符串

        """
        return_record_str = ''
        for record in self._record_list:
            return_record_str += record
            return_record_str += '\n'

        self._record_count = 0
        self._record_list.clear()

        return return_record_str



from rains.kit.web import *
from rains.common.run_pool import RunPool


class Task01(WebTask):

    def __init__(self):
        self.text = '123'

    def set_function_starting(self):
        self.plant.view.to_url('http://www.baidu.com/')

    def case_01(self):
        print(self.text)
        self.plant.element(
            page='N',
            name='N',
            by_key='xpath',
            by_value='/html/body/div[1]/div[1]/div[5]/div/div/form/span[1]/input'
        ).input.send('测试测试')


RunPool(
    cores=[WebCore(), WebCore(), WebCore()],
    tasks=[Task01, Task01, Task01]
).running()



from rains.kit.web.task import WebTask
from rains.kit.web.core import WebCore
from rains.kit.web.plant import WebPlant
from rains.kit.web.plant import BY
from rains.kit.web.model import WebModel

__all__ = ['WebTask', 'WebCore', 'WebPlant', 'BY', 'WebModel']



# !/usr/bin/env python
# coding:utf-8

# Copyright (c) 2021. quinn.7@foxmail.com All rights reserved.

# Based on the Apache License 2.0 open source protocol.

__author__ = 'quinn.7@foxmail.com'


import traceback

from flask import jsonify
from flask import request

from rains.common.db.database import Database


# 数据库实例
DB: Database = Database()


def get_request_parameters(*paras):
    """
    解析请求参数

    * 解析请求接口时携带的参数。

    Args:
        paras (): 需要解析的参数名称列表

    Return:
        dict

    """

    try:
        # 判断用户请求模式
        request_handle = request.args
        if request.method == 'POST':
            request_handle = request.form

        # 获取请求参数
        return_para_dict = {}
        for para_name in paras:
            para_value = request_handle.get(para_name)
            return_para_dict.update({para_name: para_value})

        return return_para_dict

    except BaseException as e:
        raise Exception(f"解析请求参数时发生了异常:: { e }")


def successful(return_paras: dict or None):
    """
    请求成功的返回参数

    Args:
        return_paras (dict or None): 返回数据字典

    Return:
        dict

    """

    try:
        base_return = {
            'code': 200,
            'message': '请求成功',
            'data': {}
        }

        if return_paras:
            base_return['data'] = return_paras

        return jsonify(base_return)

    except Exception as e:
        raise Exception(f"API返回数据时发生了异常:: { e }")


def unsuccessful(err_message: str):
    """
    请求失败的返回参数

    Args:
        err_message (str): 返回的错误信息

    Return:
        dict

    """

    try:
        base_return = {
            'code': 500,
            'message': '请求失败',
            'err': err_message
        }

        return jsonify(base_return)

    except Exception as e:
        raise Exception(f"API返回数据时发生了异常:: { e }")



# !/usr/bin/env python
# coding:utf-8

# Copyright (c) 2021. quinn.7@foxmail.com All rights reserved.

# Based on the Apache License 2.0 open source protocol.

__author__ = 'quinn.7@foxmail.com'


from flask import Flask
from flask import render_template

from rains.common.db.sql import Sql
from rains.common.api.common import *


app = Flask(__name__)
app.config['JSON_AS_ASCII'] = False


@app.route('/', methods=['GET'])
@app.route('/home', methods=['GET'])
def home():
    """
    首页模板
    """
    return render_template(r'home.html', ico='/resource/orange.ico')
